@@ -2,23 +2,21 @@ from collections import OrderedDict
 
 from django import forms
 from django.utils.translation import ugettext_lazy as _
-
 from wagtailstreamforms.fields import get_fields
 from wagtailstreamforms.utils.general import get_slug_from_string
 
 
 class BaseForm(forms.Form):
     def __init__(self, *args, **kwargs):
-        kwargs.setdefault('label_suffix', '')
+        kwargs.setdefault("label_suffix", "")
 
-        self.user = kwargs.pop('user', None)
-        self.page = kwargs.pop('page', None)
+        self.user = kwargs.pop("user", None)
+        self.page = kwargs.pop("page", None)
 
         super().__init__(*args, **kwargs)
 
 
 class FormBuilder:
-
     def __init__(self, fields):
         self.fields = fields
 
@@ -31,23 +29,24 @@ class FormBuilder:
         registered_fields = get_fields()
 
         for field in self.fields:
-            field_type = field.get('type')
-            field_value = field.get('value')
+            field_type = field.get("type")
+            field_value = field.get("value")
 
             # check we have the field
             if field_type not in registered_fields:
                 raise AttributeError(
-                    'Could not find a registered field of type %s' % field_type
+                    "Could not find a registered field of type %s" % field_type
                 )
 
             # check there is a label
-            if 'label' not in field_value:
+            if "label" not in field_value:
                 raise AttributeError(
-                    'The block for %s must contain a label of type blocks.CharBlock(required=True)' % field_type
+                    "The block for %s must contain a label of type blocks.CharBlock(required=True)"
+                    % field_type
                 )
 
             # slugify the label for the field name
-            field_name = get_slug_from_string(field_value.get('label'))
+            field_name = get_slug_from_string(field_value.get("label"))
 
             # get the field
             registered_cls = registered_fields[field_type]()
@@ -55,21 +54,19 @@ class FormBuilder:
             formfields[field_name] = field_cls
 
         # add fields to uniquely identify the form
-        formfields['form_id'] = forms.CharField(widget=forms.HiddenInput)
-        formfields['form_reference'] = forms.CharField(widget=forms.HiddenInput)
+        formfields["form_id"] = forms.CharField(widget=forms.HiddenInput)
+        formfields["form_reference"] = forms.CharField(widget=forms.HiddenInput)
 
         return formfields
 
     def get_form_class(self):
-        return type(str('StreamformsForm'), (BaseForm,), self.formfields)
+        return type(str("StreamformsForm"), (BaseForm,), self.formfields)
 
 
 class SelectDateForm(forms.Form):
     date_from = forms.DateTimeField(
-        required=False,
-        widget=forms.DateInput(attrs={'placeholder': _('Date from')})
+        required=False, widget=forms.DateInput(attrs={"placeholder": _("Date from")})
     )
     date_to = forms.DateTimeField(
-        required=False,
-        widget=forms.DateInput(attrs={'placeholder': _('Date to')})
+        required=False, widget=forms.DateInput(attrs={"placeholder": _("Date to")})
     )
